@@ -74,6 +74,7 @@ const TestInfo tests[] = {
 	{ "basic/predicate-variable-3", "basic/data-1", FALSE },
 	{ "basic/predicate-variable-4", "basic/data-1", FALSE },
 	{ "basic/urn-in-as", "basic/data-1", FALSE },
+	{ "basic/codepoint-escaping", "basic/data-1", FALSE },
 	{ "bnode/query-1", "bnode/data", FALSE },
 	{ "bnode/query-2", "bnode/data", FALSE },
 	{ "bnode/query-3", "bnode/data", FALSE },
@@ -149,6 +150,9 @@ const TestInfo tests[] = {
 	{ "bind/bind2", "bind/data", FALSE },
 	{ "bind/bind3", "bind/data", FALSE },
 	{ "bind/bind4", "bind/data", FALSE },
+	{ "bind/bind5", "bind/data", FALSE },
+	{ "bind/bind6", "bind/data", FALSE },
+	{ "bind/bind7", "bind/data", FALSE },
 	/* Property paths */
 	{ "property-paths/inverse-path-1", "property-paths/data", FALSE },
 	{ "property-paths/inverse-path-2", "property-paths/data", FALSE },
@@ -176,6 +180,7 @@ const TestInfo tests[] = {
 	{ "update/delete-data-query-2", "update/delete-data-2", FALSE, TRUE },
 	{ "update/delete-where-query-1", "update/delete-where-1", FALSE, FALSE },
 	{ "update/delete-where-query-2", "update/delete-where-2", FALSE, FALSE },
+	{ "update/delete-where-query-3", "update/delete-where-3", FALSE, FALSE },
 	{ "update/invalid-insert-where-query-1", "update/invalid-insert-where-1", FALSE, TRUE },
 	{ "update/delete-insert-where-query-1", "update/delete-insert-where-1", FALSE, FALSE },
 	{ "update/delete-insert-where-query-2", "update/delete-insert-where-2", FALSE, FALSE },
